@@ -1,9 +1,9 @@
-# @(#)$Id: Programs.pm 270 2013-04-14 18:38:18Z pjf $
+# @(#)$Id: Programs.pm 277 2013-04-21 20:02:29Z pjf $
 
 package Class::Usul::Programs;
 
 use attributes ();
-use version; our $VERSION = qv( sprintf '0.13.%d', q$Rev: 270 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.14.%d', q$Rev: 277 $ =~ /\d+/gmx );
 
 use Class::Inspector;
 use Class::Usul::IPC;
@@ -13,18 +13,18 @@ use Class::Usul::Constants;
 use Class::Usul::Functions qw(abs_path app_prefix arg_list assert_directory
                               class2appdir classdir elapsed env_prefix
                               exception find_source is_arrayref is_hashref
-                              is_member prefix2class say throw
-                              untaint_identifier untaint_path);
+                              is_member say throw untaint_identifier
+                              untaint_path);
+use Config;
 use Encode                 qw(decode);
 use English                qw(-no_match_vars);
 use File::Basename         qw(dirname);
+use File::HomeDir          qw();
 use File::Spec::Functions  qw(catdir catfile);
 use IO::Interactive        qw(is_interactive);
 use List::Util             qw(first);
-use Config;
 use Pod::Man;
 use Pod::Usage;
-use File::HomeDir          qw();
 use Term::ReadKey;
 use Text::Autoformat;
 use Try::Tiny;
@@ -34,6 +34,8 @@ with    q(MooseX::Getopt::Dashes);
 with    q(Class::Usul::TraitFor::LoadingClasses);
 with    q(Class::Usul::TraitFor::UntaintedGetopts);
 
+# Override attributes in base class
+
 has '+config_class' => default => sub { 'Class::Usul::Config::Programs' };
 
 has '+debug'        => traits => [ 'Getopt' ], cmd_aliases => q(D),
@@ -41,6 +43,7 @@ has '+debug'        => traits => [ 'Getopt' ], cmd_aliases => q(D),
 
 has '+help_flag'    => cmd_aliases => [ qw(usage ?) ];
 
+# Public attributes
 
 has 'help_options' => is => 'ro', isa => Bool, default => FALSE,
    documentation   => 'Uses Pod::Usage to describe the program options',
@@ -80,6 +83,7 @@ has 'version'      => is => 'ro', isa => Bool, default => FALSE,
    documentation   => 'Displays the version number of the program class',
    traits          => [ 'Getopt' ], cmd_aliases => q(V), cmd_flag => 'version';
 
+# Private attributes
 
 has '_file'        => is => 'lazy', isa => FileType,
    default         => sub { Class::Usul::File->new( builder => $_[ 0 ] ) },
@@ -115,7 +119,7 @@ around 'BUILDARGS' => sub {
 
    my $cfg = $attr->{config} ||= {};
 
-   $cfg->{appclass} ||= delete $attr->{appclass} || prefix2class $PROGRAM_NAME;
+   $cfg->{appclass} ||= delete $attr->{appclass} || blessed $self || $self;
    $cfg->{home    } ||= __find_apphome( $cfg->{appclass}, $attr->{home} );
    $cfg->{cfgfiles} ||= __get_cfgfiles( $cfg->{appclass},  $cfg->{home} );
 
@@ -469,7 +473,7 @@ sub _get_run_method {
 
    $method ||= 'run_chain'; $method eq 'run_chain' and $self->quiet( TRUE );
 
-   return $method;
+   return $self->method( $method );
 }
 
 sub _man_page_from {
@@ -753,7 +757,7 @@ Class::Usul::Programs - Provide support for command line programs
 
 =head1 Version
 
-This document describes Class::Usul::Programs version 0.13.$Revision: 270 $
+This document describes Class::Usul::Programs version 0.14.$Revision: 277 $
 
 =head1 Synopsis
 
