@@ -1,10 +1,10 @@
-# @(#)$Id: LoadingClasses.pm 270 2013-04-14 18:38:18Z pjf $
+# @(#)$Id: LoadingClasses.pm 277 2013-04-21 20:02:29Z pjf $
 
 package Class::Usul::TraitFor::LoadingClasses;
 
 use strict;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.13.%d', q$Rev: 270 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.14.%d', q$Rev: 277 $ =~ /\d+/gmx );
 
 use Moose::Role;
 use Class::MOP;
@@ -74,7 +74,7 @@ sub setup_plugins {
    my $exclude = delete $config->{exclude_pattern} || q(\A \z);
    my @paths   = @{ delete $config->{search_paths} || [] };
    my $finder  = Module::Pluggable::Object->new
-      ( search_path => [ map { m{ \A :: }mx ? __PACKAGE__.$_ : $_ } @paths ],
+      ( search_path => [ map { m{ \A :: }mx ? "Class::Usul${_}" : $_ } @paths ],
         %{ $config } );
    my @plugins = grep { not m{ $exclude }mx }
                  sort { length $a <=> length $b } $finder->plugins;
@@ -96,7 +96,7 @@ Class::Usul::TraitFor::LoadingClasses - Load classes at runtime
 
 =head1 Version
 
-0.13.$Revision: 270 $
+0.14.$Revision: 277 $
 
 =head1 Synopsis
 
